function accelPlots()
% plot acceleration time history and response spectra at a particular location
close all

[a, nNode, nStep, allTimes] = getAccel();

% plotting variables
dT = 0.02;
T  = dT*nStep;
t  = linspace(0, T, nStep)';

% plot horizontal acceleration time history at ground surface
mNode = nNode;

figure(1)
    plot(t, a(:,1,mNode), '-b','linewidth',1.5)
	grid on
	box on
    axis([0 80 -0.6 0.6])
	xlabel('time (sec)','fontsize',16)
	ylabel('acceleration (g)','fontsize',16)
    set(gca,'fontsize',14)

% build response spectra
[p, umax, vmax, amax] = respSpectra(a(:,1,mNode), T, nStep);

figure(2)
    subplot(3,1,1)
        plot(p, amax, 'b','linewidth',1.5)
        grid on 
		box on
		ylabel('S_a  (g)','fontsize',16)
		set(gca,'XtickLabel',[],'fontsize',16)
	subplot(3,1,2)
        plot(p, vmax,'b', 'linewidth',1.5)
		grid on 
		box on
		ylabel('S_v  (m/s)','fontsize',16)
        set(gca,'XtickLabel',[],'fontsize',16)
    subplot(3,1,3)
        plot(p, umax, 'b','linewidth',1.5)
		grid on 
		box on
		ylabel('S_d  (m)','fontsize',16)
		xlabel('Period, T (sec)','fontsize',16)
        set(gca,'fontsize',16)

return
